@@ -7,21 +7,22 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
+#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
 #include "types.h"
-#include "utils.h"
+
 #include "conversion.h"
 
 static unsigned short rus[] =
@@ -44,11 +45,11 @@ static unsigned short rus[] =
 	0x91D2, 0x90D2, 0x94D1, 0x84D0, 0x96D1, 0x86D0, 0x97D1, 0x87D0,
 	// ў, Ў
 	0x9ED1, 0x8ED0,
-	// ², é, è, ç, à, ù, °, ¨, £, µ, §
+	// ?, e, e, c, a, u, °, ?, ?, µ, §
 	0xb2c2, 0xa9c3, 0xa8c3, 0xa7c3, 0xa0c3, 0xb9c3, 0xb0c2, 0xa8c2, 0xa3c2, 0xb5c2, 0xa7c2,
-	//ü, û, ö, ô, ë, ê, ĵ, ï, î,
+	//u, u, o, o, e, e, j, i, i,
 	0xbcc3, 0xbbc3, 0xb6c3, 0xb4c3, 0xabc3, 0xaac3, 0xb5c4, 0xafc3, 0xaec3,
-	//Ü, Û, Ö, Ô, Ë, Ê, Ĵ, Ï, Î, À,
+	//U, U, O, O, E, E, J, I, I, A,
 	0x9cc3, 0x9bc3, 0x96c3, 0x94c3, 0x8bc3, 0x8ac3, 0xb4c4, 0x8fc3, 0x8ec3, 0x80c3
 };
 
@@ -72,11 +73,11 @@ static const char *translit[] =
 	"?\0", "?\0", "e\0", "E\0", "i\0", "I\0", "i\0", "I\0",
 	// ў, Ў
 	"?\0", "?\0",
-	// ², é, è, ç, à, ù, °, ¨, £, µ, §
+	// ?, e, e, c, a, u, °, ?, ?, µ, §
 	"?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0",
-	//ü, û, ö, ô, ë, ê, ĵ, ï, î,
+	//u, u, o, o, e, e, j, i, i,
 	"?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0",
-	//Ü, Û, Ö, Ô, Ë, Ê, Ĵ, Ï, Î, À,
+	//U, U, O, O, E, E, J, I, I, A,
 	"?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0", "?\0"
 };
 
@@ -84,8 +85,7 @@ static const int rus_len = sizeof(rus) / sizeof(rus[0]);
 
 static const char* get_translit(const char *sym)
 {
-	int i;
-	for (i = 0; i < rus_len; i++)
+	for (int i = 0; i < rus_len; i++)
 	{
 		unsigned short usym = *(unsigned short*) sym;
 		if (rus[i] == usym)
@@ -94,13 +94,14 @@ static const char* get_translit(const char *sym)
 	return NULLSYM;
 }
 
-char* convert_text_to_translit(const char *text)
+void convert_text_to_translit(char **work_text)
 {
-	int i, j, len = strlen(text);
+	char *text = *work_text;
+	int j = 0, len = strlen(text);
 
-	char *trans_text = (char *)xnmalloc((len * 3 + 1) * sizeof(char));
+	char *trans_text = (char *) malloc((len * 3 + 1) * sizeof(char));
 
-	for(i = 0, j = 0; i < len; i++)
+	for (int i = 0; i < len; i++)
 	{
 		if (isascii(text[i]))
 		{
@@ -126,5 +127,7 @@ char* convert_text_to_translit(const char *text)
 	}
 
 	trans_text[j] = NULLSYM;
-	return trans_text;
+
+	free(*work_text);
+	*work_text = trans_text; 
 }
