@@ -7,13 +7,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
@@ -21,6 +21,8 @@
 #define _CONFIG_MAIN_H_
 
 #define CONFIG_NAME			"xneurrc"
+#define CONFIG_BCK_NAME			"xneurrc~"
+#define LOG_NAME			"xneurlog"
 
 #define DICT_NAME			"dict"
 #define PROTO_NAME			"proto"
@@ -28,25 +30,40 @@
 #define LANGDEF_NAME			"langdef"
 #define REGEXP_NAME			"regexp"
 
-#define AUTO_MODE			0
-#define MANUAL_MODE			1
-
-#define MOUSE_GRAB_DISABLE		0
-#define MOUSE_GRAB_ENABLE		1
-
-#define EDUCATION_MODE_DISABLE		0
-#define EDUCATION_MODE_ENABLE		1
-
-#define LAYOUTE_REMEMBER_DISABLE	0
-#define LAYOUTE_REMEMBER_ENABLE		1
-
-#define SELECTION_SAVE_DISABLED		0
-#define SELECTION_SAVE_ENABLED		1
-
-#define NO_LANGUAGE			-1
+#define SOUNDDIR			"sounds"
+#define PIXMAPDIR			"pixmaps"
 
+#define MAX_FLAGS			4
+#define MAX_SOUNDS			14
 #define MAX_HOTKEYS			10
 
+enum _flag_action
+{
+	FLAG_LAYOUT_0 = 0,
+	FLAG_LAYOUT_1,
+	FLAG_LAYOUT_2,
+	FLAG_LAYOUT_3,
+};
+
+enum _sound_action
+{
+	SOUND_PRESS_KEY_LAYOUT_0 = 0,
+	SOUND_PRESS_KEY_LAYOUT_1,
+	SOUND_PRESS_KEY_LAYOUT_2,
+	SOUND_PRESS_KEY_LAYOUT_3,
+	SOUND_ENABLE_LAYOUT_0,
+	SOUND_ENABLE_LAYOUT_1,
+	SOUND_ENABLE_LAYOUT_2,
+	SOUND_ENABLE_LAYOUT_3,
+	SOUND_AUTOMATIC_CHANGE_WORD,
+	SOUND_MANUAL_CHANGE_WORD,
+	SOUND_CHANGE_STRING,
+	SOUND_CHANGE_SELECTED,
+	SOUND_TRANSLIT_SELECTED,
+	SOUND_CHANGECASE_SELECTED,
+	SOUND_NONE,
+};
+
 enum _hotkey_action
 {
 	ACTION_CHANGE_WORD = 0,
@@ -82,6 +99,7 @@ struct _xneur_language
 {
 	char *dir;
 	char *name;
+	int  group;
 
 	char *vowel_letter;
 	char *consonant_letter;
@@ -96,58 +114,75 @@ struct _xneur_language
 
 struct _xneur_hotkey
 {
-	char *modifier1; // Shift
-	char *modifier2; // Control 
-	char *modifier3; // Alt
-	char *modifier4; // Super (Win)
+	int modifiers; // Shift (0x1), Control (0x2), Alt (0x4), Super (0x8)
 	char *key;
 };
 
+struct _xneur_file
+{
+	char *file;
+};
+
 struct _xneur_data
 {
-	int xneur_pid;
-	int xneur_mode;
+	int process_id;
+	int manual_mode;
 };
 
 struct _xneur_config
 {
-	void (*get_library_api_version) (int *major_version, int *minor_version); // This function MUST be first
+	char *version;
+
+	void (*get_library_version) (int *major_version, int *minor_version); // This function MUST be first
 
 	struct _list_char *excluded_apps;
 	struct _list_char *auto_apps;
 	struct _list_char *manual_apps;
+	struct _list_char *layout_remember_apps;
 	struct _list_char *window_layouts;
 
 	struct _xneur_data *xneur_data;
 	struct _xneur_language *languages;		// Array of languages used in program
-	struct _xneur_hotkey hotkeys[MAX_HOTKEYS];	// Array of hotkeys used in program
+	struct _xneur_hotkey *hotkeys;			// Array of hotkeys used in program
+	struct _xneur_file *sounds;			// Array of sounds for actions
 
-	int   total_languages;				// Total languages to work with
 	int   log_level;				// Maximum level of log messages to print
-	int   *xkb_groups;				// XKB Group for each language
+	int   send_delay;				// Delay before send event (in milliseconds)
+	int   total_languages;				// Total languages to work with
 
-	int   default_group; // Initial keyboard layout for all new applications
-	
-	int   mouse_processing_mode;			// Grab or not mouse
-	int   education_mode;				// Education xneur
-	int   layout_remember_mode;			// Remember layout for each of window
-	int   save_selection_mode;			// Save selection after convert
+	int   default_group;				// Initial keyboard layout for all new applications
+
+	int   play_sounds;				// Play sound samples or not
+	int   grab_mouse;				// Grab mouse or not
+	int   educate;					// Education xneur
+	int   remember_layout;				// Remember layout for each of window
+	int   save_selection;				// Save selection after convert
+	int   save_keyboard_log;			// Save keyboard log
+
+	struct _list_char *draw_flag_apps;
+	struct _xneur_file *flags;			// Array of flag pixmaps for draw
+
+	char* (*get_home_dict_path) (const char *dir_name, const char *file_name);
+	char* (*get_global_dict_path) (const char *dir_name, const char *file_name);
+	const char* (*get_bool_name) (int option);
 
 	int   (*load) (struct _xneur_config *p);
+	void  (*clear) (struct _xneur_config *p);
 	int   (*save) (struct _xneur_config *p);
-	void  (*save_dicts) (struct _xneur_config *p);
+	int   (*replace) (struct _xneur_config *p);
+	void  (*reload) (struct _xneur_config *p);
+	int   (*kill) (struct _xneur_config *p);
+	void  (*save_dicts) (struct _xneur_config *p, int lang);
 	void  (*set_pid) (struct _xneur_config *p, int pid);
 	int   (*get_pid) (struct _xneur_config *p);
-	void  (*set_current_mode) (struct _xneur_config *p, int mode);
-	int   (*get_current_mode) (struct _xneur_config *p);
+	void  (*set_manual_mode) (struct _xneur_config *p, int manual_mode);
+	int   (*is_manual_mode) (struct _xneur_config *p);
 	char* (*get_lang_dir) (struct _xneur_config *p, int lang);
 	char* (*get_lang_name) (struct _xneur_config *p, int lang);
-	int   (*find_group_lang) (struct _xneur_config *p, int group);
 	int   (*get_lang_group) (struct _xneur_config *p, int lang);
-	char* (*get_dict_path) (const char *dir_name, const char *file_name);
-	void  (*reload_config) (struct _xneur_config *p);
-	int   (*kill) (struct _xneur_config *p);
-	void  (*set_languages) (struct _xneur_config *p, char **lang_name, char **lang_dir, int *lang_group, int total_lang);
+	int   (*find_group_lang) (struct _xneur_config *p, int group);
+	void  (*add_language) (struct _xneur_config *p, const char *name, const char *dir, int group);
+	const char* (*get_log_level_name) (struct _xneur_config *p);
 	void  (*uninit) (struct _xneur_config *p);
 };
 
