@@ -7,13 +7,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
@@ -23,16 +23,14 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#include "utils.h"
+#include "types.h"
 #include "list_char.h"
 #include "log.h"
-#include "types.h"
 
 #include "xnconfig_files.h"
 
-#define DEFAULT_MAX_PATH 4096
-
-#define HOME_CONF_DIR ".xneur"
+#define HOME_CONF_DIR		".xneur"
+#define DEFAULT_MAX_PATH	4096
 
 static int get_max_path_len(void)
 {
@@ -42,71 +40,51 @@ static int get_max_path_len(void)
 	return max_path_len;
 }
 
-static void copy_file_to_HOME(const char *dir_name, const char *file_name)
+static char* get_file_content(const char *file_name)
 {
-	int max_path_len = get_max_path_len();
+	struct stat sb;
 
-	char *path_file = (char *) xnmalloc((max_path_len + 1) * sizeof(char));
+	if (stat(file_name, &sb) != 0 || sb.st_size < 0)
+		return NULL;
 
-	// Search conf in /{prefix}/etc/xneur
-	if (dir_name == NULL)
-		snprintf(path_file, max_path_len, PACKAGE_SYSCONFDIR_DIR "/%s", file_name);
-	else
-		snprintf(path_file, max_path_len, PACKAGE_SYSCONFDIR_DIR "/%s/%s", dir_name, file_name);
-
-	FILE *stream = stream = fopen(path_file, "r");
+	FILE *stream = fopen(file_name, "rb");
 	if (stream == NULL)
-	{
-		// Search conf in /etc/xneur
-		if (dir_name == NULL)
-			snprintf(path_file, max_path_len, "/etc/xneur/%s", file_name);
-		else
-			snprintf(path_file, max_path_len, "/etc/xneur/%s/%s", dir_name, file_name);
+		return NULL;
 
-		stream = fopen(path_file, "r");
-		if (stream == NULL)
-		{
-			free(path_file);
-			return;
-		}
+	unsigned int file_len = sb.st_size;
+	
+	char *content = (char *) malloc((file_len + 2) * sizeof(char)); // + 1 '\0'
+	if (fread(content, 1, file_len, stream) != file_len)
+	{
+		free(content);
+		fclose(stream);
+		return NULL;
 	}
 
+	content[file_len] = '\0';
 	fclose(stream);
 
-	char *file_content = get_file_content(path_file);
-
-	// Copy file to HOME
-
-	// Create directory
-	if (dir_name == NULL)
-		snprintf(path_file, max_path_len, "%s/%s", getenv("HOME"), HOME_CONF_DIR);
-	else
-		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name);
-
-	mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-
-	// Create file
-	if (dir_name == NULL)
-		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, file_name);
-	else
-		snprintf(path_file, max_path_len, "%s/%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name, file_name);
-
-	stream = fopen(path_file, "w");
-	if (stream != NULL)
-	{
-		fputs(file_content, stream);
-		fclose(stream);
-	}
-
-	free(path_file);
+	return content;
 }
 
 char* get_file_path_name(const char *dir_name, const char *file_name)
 {
+#define SEARCH_IN(DIRECTORY) \
+	if (dir_name == NULL)\
+		snprintf(path_file, max_path_len, "%s/%s", DIRECTORY, file_name);\
+	else\
+		snprintf(path_file, max_path_len, "%s/%s/%s", DIRECTORY, dir_name, file_name);\
+	stream = fopen(path_file, "r");\
+	if (stream != NULL)\
+	{\
+		fclose(stream);\
+		return path_file;\
+	}
+
 	int max_path_len = get_max_path_len();
 
-	char *path_file = (char *) xnmalloc((max_path_len + 1) * sizeof(char));
-
+	char *path_file = (char *) malloc((max_path_len + 1) * sizeof(char));
+	
 	// Search conf in ~/.xneur
 	if (dir_name == NULL)
 		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, file_name);
@@ -120,92 +98,81 @@ char* get_file_path_name(const char *dir_name, const char *file_name)
 		return path_file;
 	}
 
-	// If not find, then copy from system dir.
-	copy_file_to_HOME(dir_name, file_name);
+	SEARCH_IN(PACKAGE_SYSCONFDIR_DIR);
+	SEARCH_IN("/etc/xneur");
+	SEARCH_IN(PACKAGE_SHAREDIR_DIR);
+
+	// Returning default in ~/.xneur
+	if (dir_name == NULL)
+		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, file_name);
+	else
+		snprintf(path_file, max_path_len, "%s/%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name, file_name);
 
 	return path_file;
 }
 
-char* get_file_content(const char *file_name)
+char* get_home_file_path_name(const char *dir_name, const char *file_name)
 {
-	struct stat sb;
+	int max_path_len = get_max_path_len();
 
-	if (stat(file_name, &sb) != 0 || sb.st_size < 0)
-		return NULL;
-
-	FILE *stream = fopen(file_name, "r");
-	if (stream == NULL)
-		return NULL;
-
-	unsigned int file_len = sb.st_size;
-
-	char *content = (char *) xnmalloc((file_len + 2) * sizeof(char)); // + 1 '\n' + 1 '\0'
-	if (fread(content, 1, file_len, stream) != file_len)
+	char *path_file = (char *) malloc((max_path_len + 1) * sizeof(char));
+	
+	if (dir_name == NULL)
 	{
-		free(content);
-		fclose(stream);
-		return NULL;
+		snprintf(path_file, max_path_len, "%s/%s", getenv("HOME"), HOME_CONF_DIR); 
+		mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH); 
+
+		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, file_name);
 	}
+	else
+	{
+		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name);
+		mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
 
-	content[file_len] = '\n';
-	content[file_len + 1] = '\0';
-	fclose(stream);
-
-	return content;
+		snprintf(path_file, max_path_len, "%s/%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name, file_name);
+	}
+	return path_file;
 }
 
-char* get_file_content_path(const char *dir_name, const char *file_name)
+struct _list_char* load_list(const char *dir_name, const char *file_name, int sort_flag)
 {
-        char *file_path_name = get_file_path_name(dir_name, file_name);
+	char *file_path_name = get_file_path_name(dir_name, file_name);
 
 	char *content = get_file_content(file_path_name);
-
-	free(file_path_name);
-
-	return content;
-}
-
-struct _list_char* load_list_from_file(const char *dir_name, const char *file_name)
-{
-	char *content = get_file_content_path(dir_name, file_name);
 	if (content == NULL)
-		return NULL;
-
-	struct _list_char *data = list_char_init();
-
-	int len = strlen(content);
-
-	int sym, last_sym = 0;
-	for (sym = 0; sym < len; sym++)
 	{
-		if (content[sym] != '\n')
-			continue;
-
-		if (last_sym == sym)
-		{
-			last_sym++;
-			continue;
-		}
-
-		content[sym] = '\0';
-		data->add(data, content + last_sym);
-
-		last_sym = sym + 1;
+		free(file_path_name);
+		return NULL;
 	}
 
+	struct _list_char *list = list_char_init();
+
+	list->load(list, content);
+
 	free(content);
-	return data;
+	free(file_path_name);
+
+	if (sort_flag == TRUE)
+		list->sort(list);
+
+	return list;
 }
 
-void save_list_to_file(struct _list_char *list, const char *file_name)
+int save_list(struct _list_char *list, const char *dir_name, const char *file_name)
 {
-	FILE *stream = fopen(file_name, "w");
-	if (stream == NULL)
-		return;
+	char *file_path_name = get_home_file_path_name(dir_name, file_name);
 
-	int i;
-	for (i = 0; i < list->data_count; i++)
-		fprintf(stream, "%s\n", list->data[i].string);
+	FILE *stream = fopen(file_path_name, "w");
+	if (stream == NULL)
+	{
+		free(file_path_name);
+		return FALSE;
+	}
+
+	list->save(list, stream);
 
 	fclose(stream);
+	free(file_path_name);
+
+	return TRUE;
 }
