@@ -7,22 +7,21 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
+#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdarg.h>
-#include <stdlib.h>
 
-#include "types.h"
 #include "colors.h"
 
 #include "log.h"
@@ -65,13 +64,18 @@ void log_message(int level, const char *string, ...)
 			modifier = TEAL_COLOR "[DBG]: " NORMAL_COLOR;
 			break;
 		}
+		case TRACE:
+		{
+			modifier = BLUE_COLOR "[TRA]: " NORMAL_COLOR;
+			break;
+		}
 	}
 
 	int len = strlen(string) + strlen(modifier) + 2;
 
 	char *buffer = (char *) malloc(len + 1);
 	snprintf(buffer, len, "%s%s\n", modifier, string);
-	buffer[len] = NULLSYM;
+	buffer[len] = 0;
 
 	va_list ap;
 	va_start(ap, string);
