@@ -7,22 +7,26 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
 #ifndef _XDEFINES_H_
 #define _XDEFINES_H_
 
-#define INPUT_HANDLE_MASK	KeyReleaseMask  | PropertyChangeMask
+#define INPUT_HANDLE_MASK	PropertyChangeMask
+#define EVENT_PRESS_MASK	KeyPressMask 
+#define EVENT_RELEASE_MASK	KeyReleaseMask 
+#define POINTER_MOTION_MASK	PointerMotionMask
 #define FOCUS_CHANGE_MASK	LeaveWindowMask | EnterWindowMask | FocusChangeMask
-#define MAIN_WINDOW_MASK	StructureNotifyMask
-#define BUTTON_HANDLE_MASK	Button1MotionMask | ButtonPressMask | ButtonReleaseMask
+#define BUTTON_HANDLE_MASK	ButtonPressMask
+
+static const int groups[4] = {0x00000000, 0x00002000, 0x00004000, 0x00006000};
 
 #endif /* _XDEFINIES_H_ */
