@@ -7,13 +7,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
@@ -39,8 +39,8 @@ struct _xevent
 	int (*get_cur_modifiers) (struct _xevent *p);
 
 	int  (*get_next_event) (struct _xevent *p);
+	void (*send_next_event) (struct _xevent *p);
 	void (*set_owner_window) (struct _xevent *p, Window window);
-	void (*send_xkey) (struct _xevent *p, KeyCode kc, int modifiers);
 	void (*send_string) (struct _xevent *p, struct _xstring *str);
 	void (*send_backspaces) (struct _xevent *p, int n);
 	void (*send_selection) (struct _xevent *p, int n);
