@@ -7,13 +7,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2007
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
@@ -22,34 +22,28 @@
 
 #include <X11/Xutil.h>
 
-int  get_keycode_mod(int keyboard_group);
-int  get_languages_mask(void);
-void get_keysyms_by_string(char *keyname, KeySym *Lower, KeySym *Upper);
-
-struct _xkeymap_alpha
-{
-	char *lower_sym;
-	char *upper_sym;
-};
+int   get_keycode_mod(int keyboard_group);
+int   get_languages_mask(void);
+void  get_keysyms_by_string(char *keyname, KeySym *Lower, KeySym *Upper);
+char* keycode_to_symbol(KeyCode kc, int group, int state);
 
 struct _xkeymap
 {
-
-	struct _xkeymap_alpha **alphabet;
 	KeySym *keymap;
 
 	int latin_group;
-	int latin_group_mask;	// Define latin group mask
+	int latin_group_mask;
 	int min_keycode;
 	int max_keycode;
-	int total_key_arrays;
+	int keysyms_per_keycode;
+	int keyboard_groups_count;
 
-	char* (*keycode_to_symbol)(struct _xkeymap *p, KeyCode kc, int group, int state);
 	char  (*get_ascii)(struct _xkeymap *p, const char *sym);
 	char  (*get_cur_ascii_char) (struct _xkeymap *p, XEvent e);
 	void  (*convert_text_to_ascii)(struct _xkeymap *p, char *text);
 	void  (*char_to_keycode)(struct _xkeymap *p, char ch, KeyCode *kc, int *modifier);
-	void  (*store_keymaps)(struct _xkeymap *p);
+	void  (*print_keymaps)(struct _xkeymap *p);
+	char* (*lower_by_keymaps)(struct _xkeymap *p, int gr, char *text);
 	void  (*uninit) (struct _xkeymap *p);
 };
 
