@@ -7,21 +7,19 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
 #ifndef _XPROGRAM_H_
 #define _XPROGRAM_H_
 
-void close_program(void);
-
 struct _xprogram
 {
 	struct _xswitchlang *switchlang;
@@ -29,21 +27,24 @@ struct _xprogram
 	struct _xevent *event;
 	struct _xfocus *focus;
 	struct _xstring *string;
-
+	struct _xcursor *cursor;
+	
 	int  last_action;
 	int  changed_manual;
 	int  app_forced_mode;
 	int  app_focus_mode;
 
 	int  selected_mode;
+	
 	int  modifier_mask;
-
+	
 	int  last_layout;
 	int  last_window;
 
+	void (*cursor_update) (struct _xprogram *p);
 	void (*layout_update) (struct _xprogram *p);
-	void (*update) (struct _xprogram *p, int *do_update);
-	void (*on_key_press) (struct _xprogram *p);
+	void (*update) (struct _xprogram *p);
+	void (*on_key_action) (struct _xprogram *p);
 	void (*process_input) (struct _xprogram *p);
 	int  (*perform_manual_action) (struct _xprogram *p, enum _hotkey_action action);
 	void (*perform_auto_action) (struct _xprogram *p, int action);
