@@ -7,13 +7,13 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
@@ -32,12 +32,15 @@ struct _xstring
 	int cur_pos;		// Current filled size
 
 	void (*clear) (struct _xstring *p);
+	void (*save_log) (struct _xstring *p, char *path, Window window);
+	void (*save_and_clear) (struct _xstring *p, Window window);
 	int  (*is_space_last) (struct _xstring *p);
 	void (*set_key_code) (struct _xstring *p, int group);
 	void (*set_content) (struct _xstring *p, const char *new_content);
-	void (*changecase_content) (struct _xstring *p);
+	void (*change_case) (struct _xstring *p);
 	void (*add_symbol) (struct _xstring *p, char sym, KeyCode keycode, int modifier);
 	void (*del_symbol) (struct _xstring *p);
+	char*(*get_utf_string) (struct _xstring *p);
 	void (*uninit) (struct _xstring *p);
 };
 
