@@ -7,18 +7,18 @@
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  (c) XNeur Team 2006
+ *  Copyright (C) 2006-2008 XNeur Team
  *
  */
 
 #ifdef HAVE_CONFIG_H
-#   include "config.h"
+#  include "config.h"
 #endif
 
 #include <signal.h>
@@ -26,47 +26,86 @@
 #include <stdio.h>
 #include <getopt.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "xnconfig.h"
 
 #include "xprogram.h"
+#include "xbtable.h"
+#include "xswitchlang.h"
 
+#include "types.h"
 #include "utils.h"
 #include "list_char.h"
 #include "log.h"
 #include "colors.h"
-#include "types.h"
-
-#include "newlang_creation.h"
-
-int xneur_check_lock = TRUE;
-int xneur_generate_protos = FALSE;
+#include "sound.h"
 
 struct _xneur_config *xconfig = NULL;
+static struct _xprogram *xprogram = NULL;
 
-static void xneur_exit(void)
+static int xneur_check_lock = TRUE;
+
+static void xneur_reload(int status);
+
+static void xneur_check_config_version(int final)
 {
-	close_program();
-}
+	log_message(LOG, "Checking configuration file version...");
 
-static void xneur_load_config(void)
-{
-	log_message(LOG, "Loading configuration");
+	if (xconfig->version != NULL && strcmp(xconfig->version, VERSION) == 0)
+	{
+		log_message(LOG, "User configuration file version is OK!");
+		return;
+	}
 
-	// Load configuration
-	if (!xconfig->load(xconfig))
+	log_message(ERROR, "Configuration file version is out of date!");
+
+	if (final)
 	{
 		xconfig->uninit(xconfig);
 		exit(EXIT_FAILURE);
 	}
 
-	const char *log_levels[] = {"Error", "Warning", "Log", "Debug"};
-	log_message(LOG, "Log level is set to %s", log_levels[xconfig->log_level]);
+	if (!xconfig->replace(xconfig))
+	{
+		log_message(ERROR, "Default configuration file not founded in system! Please, reinstall XNeur!");
+		xconfig->uninit(xconfig);
+		exit(EXIT_FAILURE);
+	}
+		
+	log_message(LOG, "Configuration file replaced to default one");
+	
+	xneur_reload(0);
+}
 
+static void xneur_init(void)
+{
+	if (!print_keyboard_groups())
+	{
+		xconfig->uninit(xconfig);
+		exit(EXIT_FAILURE);
+	}
+
+	bind_manual_actions();
+}
+
+static void xneur_load_config(int final)
+{
+	log_message(LOG, "Loading configuration");
+
+	if (!xconfig->load(xconfig))
+	{
+		log_message(ERROR, "Configuration file damaged! Please, remove old file before starting xneur!");
+		xconfig->uninit(xconfig);
+		exit(EXIT_FAILURE);
+	}
+	
+	xneur_check_config_version(final);
+
+	log_message(LOG, "Log level is set to %s", xconfig->get_log_level_name(xconfig));
 	log_message(LOG, "Total detected %d languages", xconfig->total_languages);
 
-	int lang;
-	for (lang = 0; lang < xconfig->total_languages; lang++)
+	for (int lang = 0; lang < xconfig->total_languages; lang++)
 	{
 		char *lang_name = xconfig->get_lang_name(xconfig, lang);
 
@@ -79,31 +118,13 @@ static void xneur_load_config(void)
 	log_message(DEBUG, "Configuration load complete");
 
 	log_message(LOG, "Default group for all new windows set to %d", xconfig->default_group);
-	
-	char *current_mode = "auto";
-	if (xconfig->get_current_mode(xconfig) == MANUAL_MODE)
-		current_mode = "manual";
-	log_message(LOG, "Current mode set to %s", current_mode);
-
-	current_mode = "Yes";
-	if (xconfig->mouse_processing_mode == MOUSE_GRAB_DISABLE)
-		current_mode = "No";
-	log_message(LOG, "Mouse processing mode set to %s", current_mode);
-
-	current_mode = "Yes";
-	if (xconfig->education_mode == EDUCATION_MODE_DISABLE)
-		current_mode = "No";
-	log_message(LOG, "Education mode set to %s", current_mode);
-
-	current_mode = "Yes";
-	if (xconfig->layout_remember_mode == LAYOUTE_REMEMBER_DISABLE)
-		current_mode = "No";
-	log_message(LOG, "Layout remember mode set to %s", current_mode);
-
-	current_mode = "Yes";
-	if (xconfig->save_selection_mode == SELECTION_SAVE_DISABLED)
-		current_mode = "No";
-	log_message(LOG, "Save selection after convertion mode set to %s", current_mode);
+	log_message(LOG, "Manual mode set to %s", xconfig->get_bool_name(xconfig->is_manual_mode(xconfig)));
+	log_message(LOG, "Mouse processing mode set to %s", xconfig->get_bool_name(xconfig->grab_mouse));
+	log_message(LOG, "Education mode set to %s", xconfig->get_bool_name(xconfig->educate));
+	log_message(LOG, "Layout remember mode set to %s", xconfig->get_bool_name(xconfig->remember_layout));
+	log_message(LOG, "Save selection mode set to %s", xconfig->get_bool_name(xconfig->save_selection));
+	log_message(LOG, "Sound playing mode set to %s", xconfig->get_bool_name(xconfig->play_sounds));
+	log_message(LOG, "Logging keyboard mode set to %s", xconfig->get_bool_name(xconfig->save_keyboard_log));
 }
 
 static void xneur_set_lock(void)
@@ -118,38 +139,66 @@ static void xneur_set_lock(void)
 		}
 	}
 
-	int xneur_pid = getpid();
+	int process_id = getpid();
 
-	xconfig->set_pid(xconfig, xneur_pid);
+	xconfig->set_pid(xconfig, process_id);
 
-	log_message(DEBUG, PACKAGE " pid is %d", xneur_pid);
+	log_message(DEBUG, PACKAGE " pid is %d", process_id);
+}
+
+static void xneur_cleanup(void)
+{
+	sound_uninit();
+	log_message(DEBUG, "Current sound data is freed");
+	
+	if (xprogram != NULL)
+		xprogram->uninit(xprogram);
+
+	log_message(DEBUG, "Current program info is freed");
+
+	if (xconfig != NULL)
+	{
+		xconfig->set_pid(xconfig, 0);
+		xconfig->uninit(xconfig);
+	}
+	log_message(DEBUG, "Current configuration data is freed");
+
+#ifdef WITH_DEBUG
+	xndebug_uninit();
+#endif
 }
 
 static void xneur_terminate(int status)
 {
-	status = status; // To prevent warnings
+	if (status){}
+
 	log_message(DEBUG, "Caught SIGTERM/SIGINT, terminating");
-	xneur_exit();
+
+	xneur_cleanup();
+
+	exit(EXIT_SUCCESS);
 }
 
 static void xneur_reload(int status)
 {
-	status = status;
+	status = status; // To prevent warnings
 	log_message(LOG, "Caught SIGHUP, reloading configuration file");
 
+	sound_uninit();
+	
 	if (xconfig != NULL)
-	{
 		xconfig->uninit(xconfig);
 
-		xconfig = xneur_config_init();
-		if (xconfig == NULL)
-		{
-			log_message(ERROR, "Can't init libxnconfig");
-			exit(EXIT_FAILURE);
-		}
+	xconfig = xneur_config_init();
+	if (xconfig == NULL)
+	{
+		log_message(ERROR, "Can't init libxnconfig");
+		exit(EXIT_FAILURE);
 	}
 
-	xneur_load_config();
+	xneur_load_config(TRUE);
+	xneur_init();
+	sound_init();
 }
 
 static void xneur_usage(void)
@@ -162,13 +211,12 @@ static void xneur_usage(void)
 	printf("  -h, --help              This help!\n");
 	printf("  -a, --about             About for " PACKAGE "\n");
 	printf("  -f, --force             Skip check for other instances of " PACKAGE " runned\n");
-	printf("  -g, --generate          Generate proto and proto3 files from alphabet and sample text files\n");
 }
 
 static void xneur_version(void)
 {
 	printf("\nXneur - automatic keyboard switcher (version %s) \n", VERSION);
-	printf("mailto: andrew.crew.kuznetsov@gmail.com\n\n");
+	printf("mailto: andrewcrew@rambler.ru\n\n");
 	printf("web: http://www.xneur.ru/\n");
 }
 
@@ -178,7 +226,7 @@ static void xneur_about(void)
 	printf("Automatic keyboard switcher (version %s) \n", VERSION);
 	printf("It's program like Punto Switcher. \n");
 	printf("This utility is made for X Window System.\n\n");
-	printf("mailto: andrew.crew.kuznetsov@gmail.com\n");
+	printf("mailto: andrewcrew@rambler.ru\n");
 	printf("web: http://www.xneur.ru/\n");
 }
 
@@ -190,7 +238,6 @@ static void xneur_get_options(int argc, char *argv[])
 			{ "help",		no_argument,	NULL,	'h' },
 			{ "about",		no_argument,	NULL,	'a' },
 			{ "force",		no_argument,	NULL,	'f' },
-			{ "generate",		no_argument,	NULL,	'g' },
 			{ NULL,			0,		NULL,	0 }
 	};
 
@@ -223,13 +270,6 @@ static void xneur_get_options(int argc, char *argv[])
 				xneur_usage();
 				break;
 			}
-			case 'g':
-			{
-				xneur_generate_protos = TRUE;
-				xneur_check_lock = FALSE;
-				opted = FALSE;
-				break;
-			}
 		}
 	}
 
@@ -240,9 +280,9 @@ static void xneur_get_options(int argc, char *argv[])
 static void xneur_reklama(void)
 {
 	printf("\n");
-	printf(LIGHT_PURPLE_COLOR "=============================================================" NORMAL_COLOR "\n");
-	printf(LIGHT_PURPLE_COLOR ">>> " LIGHT_BLUE_COLOR "Special thanks to " RED_COLOR "http://www.softodrom.ru" LIGHT_BLUE_COLOR " for support" LIGHT_PURPLE_COLOR " <<<" NORMAL_COLOR "\n");
-	printf(LIGHT_PURPLE_COLOR "=============================================================" NORMAL_COLOR "\n");
+	printf(LIGHT_PURPLE_COLOR "====================================================" NORMAL_COLOR "\n");
+	printf(LIGHT_PURPLE_COLOR ">>> " LIGHT_PURPLE_COLOR "Please visit " RED_COLOR "http://www.xneur.ru" LIGHT_BLUE_COLOR " for support" LIGHT_PURPLE_COLOR " <<<" NORMAL_COLOR "\n");
+	printf(LIGHT_PURPLE_COLOR "====================================================" NORMAL_COLOR "\n");
 	printf("\n");
 }
 
@@ -250,10 +290,8 @@ int main(int argc, char *argv[])
 {
 	xneur_reklama();
 
-	// Parse command line options
 	xneur_get_options(argc, argv);
 
-	// Init configuration
 	xconfig = xneur_config_init();
 	if (xconfig == NULL)
 	{
@@ -261,14 +299,10 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	// Set lock pid
 	xneur_set_lock();
+	xneur_load_config(FALSE);
 
-	// Load configuration file
-	xneur_load_config();
-
-	// Init program structures
-	struct _xprogram *xprogram = xprogram_init();
+	xprogram = xprogram_init();
 	if (xprogram == NULL)
 	{
 		log_message(ERROR, "Failed to init program structure");
@@ -277,23 +311,18 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
+	sound_init();
+	xneur_init();
+
 	log_message(DEBUG, "Init program structure complete");
 
 	xntrap(SIGTERM, xneur_terminate);
 	xntrap(SIGINT, xneur_terminate);
 	xntrap(SIGHUP, xneur_reload);
 
-	if (xneur_generate_protos)
-		generate_protos();
-
 	xprogram->process_input(xprogram);
 
-	xprogram->uninit(xprogram);
-	log_message(DEBUG, "Current program info is freed");
+	xneur_cleanup();
 
-	xconfig->set_pid(xconfig, 0);
-	xconfig->uninit(xconfig);
-	log_message(DEBUG, "Current configuration data is freed");
-
-	return EXIT_SUCCESS;
+	exit(EXIT_SUCCESS);
 }
